predicates

package
v0.3.26 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IgnoreTraceAnnotationUpdatePredicate

type IgnoreTraceAnnotationUpdatePredicate struct {
	predicate.Funcs
}

IgnoreTraceAnnotationUpdatePredicate implements a predicate that ignores updates where only the trace ID and span ID annotations, or resource version changes.

func (IgnoreTraceAnnotationUpdatePredicate) Update

Update implements the update event check for the predicate.

Jump to