Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IgnoreTraceAnnotationUpdatePredicate ¶
IgnoreTraceAnnotationUpdatePredicate implements a predicate that ignores updates where only the trace ID and span ID annotations, or resource version changes.
func (IgnoreTraceAnnotationUpdatePredicate) Update ¶
func (IgnoreTraceAnnotationUpdatePredicate) Update(e event.UpdateEvent) bool
Update implements the update event check for the predicate.
Click to show internal directories.
Click to hide internal directories.